# Changelog

## [2.4.3a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/2.4.3a1) (2024-11-15)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/2.4.2...2.4.3a1)

**Merged pull requests:**

- fix:lang\_dir\_crawling [\#289](https://github.com/OpenVoiceOS/OVOS-workshop/pull/289) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
